@@ -26,6 +26,7 @@ mylm<-function(x,y,w,offs=rep(0,length(y))){
     c2 <- apply((Z >= PSI), 2, all)
     if(sum(c1 + c2) != 0 || is.na(sum(c1 + c2))) stop("psi out of the range")
     #
+    digits<-opz$digits
     pow<-opz$pow
     nomiOK<-opz$nomiOK
     toll<-opz$toll
@@ -59,7 +60,7 @@ mylm<-function(x,y,w,offs=rep(0,length(y))){
         obj <- lm.wfit(x = X, y = y, w = w, offset = offs)
         dev.old<-dev.new
         dev.new <- dev.new1 <-sum(obj$residuals^2)
-        if(return.all.sol) dev.new1 <- sum(mylm(x = cbind(XREG, U), y = y, w = w, offs = offs)$residuals^2)
+        if(return.all.sol) dev.new1 <- sum(mylm(x = cbind(XREG, U), y = y, w = w, offs = offs)$residuals^2*w/sum(w))
         dev.values[[length(dev.values) + 1]] <- dev.new1
         if (visual) {
             flush.console()
@@ -88,6 +89,7 @@ mylm<-function(x,y,w,offs=rep(0,length(y))){
         psi.values[[length(psi.values) + 1]] <- psi.old <- psi
  #       if(it>=old.it.max && h<1) H<-h
         psi <- psi.old + h*gamma.c/beta.c
+        if(!is.null(digits)) psi<-round(psi, digits)
         PSI <- matrix(rep(psi, rep(nrow(Z), length(psi))), ncol = length(psi))
         #check if psi is admissible..
         a <- apply((Z <= PSI), 2, all) #prima era solo <
@@ -124,7 +126,7 @@ mylm<-function(x,y,w,offs=rep(0,length(y))){
     obj$epsilon <- epsilon
     obj$it <- it
     obj.new <- lm.wfit(x = cbind(XREG, U), y = y, w = w, offset = offs)
-    SS.new<-sum(obj.new$residuals^2)
+    SS.new<-sum(obj.new$residuals^2*w/sum(w))
     if(!gap){
           names.coef<-names(obj$coefficients)
           obj$coefficients<-c(obj.new$coefficients, rep(0,ncol(V)))
